@@ -5,7 +5,7 @@
  * libradius.h	Structures and prototypes
  *		for the radius library.
  *
- * Version:	$Id: libradius.h,v 1.50 2002/03/06 21:15:37 aland Exp $
+ * Version:	$Id: libradius.h,v 1.53 2002/07/10 19:45:35 aland Exp $
  *
  */
 
@@ -53,6 +53,12 @@
 #endif
 #endif
 
+/*
+ *  Include for modules.
+ */
+#include <sha1.h>
+#include <md4.h>
+
 #define EAP_START               2
 
 #define AUTH_VECTOR_LEN		16
@@ -84,6 +90,7 @@ typedef struct attr_flags {
 	signed char		tag;
 	char			encrypt;	/* encryption method */
 	signed char		len_disp;	/* length displacement */
+	char			do_xlat;
 } ATTR_FLAGS;
 
 typedef struct dict_attr {
@@ -215,6 +222,7 @@ VALUE_PAIR	*paircopy(VALUE_PAIR *vp);
 VALUE_PAIR	*paircopy2(VALUE_PAIR *vp, int attr);
 void		pairmove(VALUE_PAIR **to, VALUE_PAIR **from);
 void		pairmove2(VALUE_PAIR **to, VALUE_PAIR **from, int attr);
+VALUE_PAIR	*pairparsevalue(VALUE_PAIR *vp, const char *value);
 VALUE_PAIR	*pairmake(const char *attribute, const char *value, int operator);
 VALUE_PAIR	*pairread(char **ptr, LRAD_TOKEN *eol);
 LRAD_TOKEN	userparse(char *buffer, VALUE_PAIR **first_pair);
@@ -250,6 +258,7 @@ char		*strNcpy(char *dest, const char *src, int n);
 void		rad_lowercase(char *str);
 void		rad_rmspace(char *str);
 int		rad_lockfd(int fd, int lock_len);
+int		rad_lockfd_nonblock(int fd, int lock_len);
 int		rad_unlockfd(int fd, int lock_len);
 
 #ifdef ASCEND_BINARY
