@@ -1,7 +1,7 @@
 /*
  * radius.h	Constants of the radius protocol.
  *
- * Version:	$Id: radius.h,v 1.42 2002/06/11 18:09:48 aland Exp $
+ * Version:	$Id: radius.h,v 1.43 2002/07/18 08:22:30 pam Exp $
  *
  */
 
@@ -134,7 +134,7 @@
 #define PW_ACCT_SESSION_START_TIME	1050
 #define PW_ACCT_UNIQUE_SESSION_ID	1051
 #define PW_CLIENT_IP_ADDRESS		1052
-#define LDAP_USERDN			1053
+#define PW_LDAP_USERDN			1053
 #define PW_NS_MTA_MD5_PASSWORD		1054
 #define PW_SQL_USER_NAME  		1055
 #define PW_LM_PASSWORD			1057
@@ -206,7 +206,6 @@
 #define PW_AUTHTYPE_REJECT		4
 #define PW_AUTHTYPE_ACTIVCARD		5
 #define PW_AUTHTYPE_EAP                 6
-#define PW_AUTHTYPE_PAM			253
 #define PW_AUTHTYPE_ACCEPT		254
 
 /*	Port Types		*/
