@@ -4,7 +4,7 @@
  * radiusd.h	Structures, prototypes and global variables
  *		for the FreeRADIUS server.
  *
- * Version:	$Id: radiusd.h,v 1.106 2002/06/10 10:51:01 fcusack Exp $
+ * Version:	$Id: radiusd.h,v 1.109 2002/07/22 23:10:05 ramoore Exp $
  *
  */
 #include "libradius.h"
@@ -187,7 +187,6 @@ extern const char	*radius_dir;
 extern const char	*radius_libdir;
 extern radlog_dest_t	radlog_dest;
 extern uint32_t		expiration_seconds;
-extern int		use_dbm;
 extern int		log_stripped_names;
 extern uint32_t		myip;
 extern int		log_auth_detail;
@@ -262,7 +261,7 @@ NAS		*nas_findbyname(char *nasname);
 void		version(void);
 
 /* log.c */
-int radlogdir_iswritable(const char *);
+int 		radlogdir_iswritable(const char *);
 int		vradlog(int, const char *, va_list ap);
 int		radlog(int, const char *, ...)
 #ifdef __GNUC__
@@ -274,6 +273,7 @@ int		log_debug(const char *, ...)
 		__attribute__ ((format (printf, 1, 2)))
 #endif
 ;
+void 		vp_listdebug(VALUE_PAIR *vp);
 
 /* proxy.c */
 int proxy_receive(REQUEST *request);
@@ -316,6 +316,7 @@ void		xlat_unregister(const char *module, RAD_XLAT_FUNC func);
 /* threads.c */
 extern		int thread_pool_init(void);
 extern		int thread_pool_clean(time_t now);
+extern		void rad_exec_init(void);
 extern		pid_t rad_fork(int exec_wait);
 extern		pid_t rad_waitpid(pid_t pid, int *status, int options);
 extern		int rad_savepid(pid_t pid, int status);
