@@ -1,11 +1,11 @@
 /*
  * dict.c	Routines to read the dictionary file.
  *
- * Version:	$Id: dict.c,v 1.28 2001/10/31 17:01:13 cparker Exp $
+ * Version:	$Id: dict.c,v 1.30 2002/06/21 19:57:24 cparker Exp $
  *
  */
 
-static const char rcsid[] = "$Id: dict.c,v 1.28 2001/10/31 17:01:13 cparker Exp $";
+static const char rcsid[] = "$Id: dict.c,v 1.30 2002/06/21 19:57:24 cparker Exp $";
 
 #include	"autoconf.h"
 
@@ -343,7 +343,7 @@ static int my_dict_init(const char *dir, const char *fn, const char *src_file, i
 			/*
 			 *	Validate all entries
 			 */
-			if (!isdigit(*valstr)) {
+			if (!isdigit((int) *valstr)) {
 				librad_log("dict_init: %s[%d]: invalid value",
 					fn, line);
 				return -1;
@@ -404,7 +404,7 @@ static int my_dict_init(const char *dir, const char *fn, const char *src_file, i
 				}
 				else if (strncmp(s, "encrypt=", 8) == 0) {
 				          /* Encryption method, defaults to 0 (none).
-					     Currently valid is just type 1,
+					     Currently valid is just type 2,
 					     Tunnel-Password style, which can only
 					     be applied to strings. */    
 				          flags.encrypt = strtol(s + 8, &c, 0);
@@ -469,7 +469,7 @@ static int my_dict_init(const char *dir, const char *fn, const char *src_file, i
 			/*
 			 *	Validate all entries
 			 */
-			if (!isdigit(*valstr)) {
+			if (!isdigit((int) *valstr)) {
 				librad_log("dict_init: %s[%d]: invalid value",
 					fn, line);
 				return -1;
@@ -515,7 +515,7 @@ static int my_dict_init(const char *dir, const char *fn, const char *src_file, i
 			/*
 			 *	 Validate all entries
 			 */
-			if (!isdigit(*valstr)) {
+			if (!isdigit((int) *valstr)) {
 				librad_log("dict_init: %s[%d]: invalid value",
 					fn, line);
 				return -1;
