@@ -1,7 +1,7 @@
 /*
  * auth.c	User authentication.
  *
- * Version:	$Id: auth.c,v 1.106 2002/06/21 19:57:25 cparker Exp $
+ * Version:	$Id: auth.c,v 1.108 2002/07/17 18:20:56 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  */
 
-static const char rcsid[] = "$Id: auth.c,v 1.106 2002/06/21 19:57:25 cparker Exp $";
+static const char rcsid[] = "$Id: auth.c,v 1.108 2002/07/17 18:20:56 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -271,7 +271,7 @@ int rad_check_password(REQUEST *request)
 		 	*
 		 	*	This is fail-safe.
 		 	*/
-			DEBUG2("auth: No Auth-Type configuration for the request, rejecting the user");
+			DEBUG2("auth: No authenticate method (Auth-Type) configuration found for the request: Rejecting the user");
 			return -2;
 		}
 	}
@@ -822,7 +822,6 @@ autz_redo:
 				user_msg = "\r\nAccess denied (external check failed).";
 
 			request->reply->code = PW_AUTHENTICATION_REJECT;
-			pairfree(&request->reply->vps);
 			tmp = pairmake("Reply-Message", user_msg, T_OP_SET);
 			request->reply->vps = tmp;
 			
