@@ -1,7 +1,7 @@
 /*
  * files.c	Read config files into memory.
  *
- * Version:     $Id: client.c,v 1.15 2001/03/20 12:41:32 cmiller Exp $
+ * Version:     $Id: client.c,v 1.16 2002/06/17 15:34:32 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
 
-static const char rcsid[] = "$Id: client.c,v 1.15 2001/03/20 12:41:32 cmiller Exp $";
+static const char rcsid[] = "$Id: client.c,v 1.16 2002/06/17 15:34:32 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -87,7 +87,7 @@ int read_clients_file(const char *file)
 
 	while(fgets(buffer, 256, fp) != NULL) {
 		lineno++;
-		if (strchr(buffer, '\n') == NULL) {
+		if (!feof(fp) && (strchr(buffer, '\n') == NULL)) {
 			radlog(L_ERR, "%s[%d]: line too long", file, lineno);
 			return -1;
 		}
@@ -207,10 +207,10 @@ RADCLIENT *client_find(uint32_t ipaddr)
 	RADCLIENT *cl;
 	RADCLIENT *match = NULL;
 
-	for(cl = clients; cl; cl = cl->next) {
+	for (cl = clients; cl; cl = cl->next) {
 		if ((ipaddr & cl->netmask) == cl->ipaddr) {
 			if ((!match) ||
-					(ntohl(cl->netmask) > ntohl(match->netmask))) {
+			    (ntohl(cl->netmask) > ntohl(match->netmask))) {
 				match = cl;
 			}
 		}
