@@ -1,7 +1,7 @@
 /*
  * files.c	Read config files into memory.
  *
- * Version:     $Id: files.c,v 1.62 2002/03/06 17:55:39 aland Exp $
+ * Version:     $Id: files.c,v 1.66 2002/06/21 19:57:26 cparker Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
 
-static const char rcsid[] = "$Id: files.c,v 1.62 2002/03/06 17:55:39 aland Exp $";
+static const char rcsid[] = "$Id: files.c,v 1.66 2002/06/21 19:57:26 cparker Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -104,6 +104,7 @@ static void auth_type_fixup(VALUE_PAIR **check)
 	}
 	vp->lvalue = n;
 	vp->operator = T_OP_ADD;
+	strcpy(vp->strvalue, "Local");
 
 	vp->next = *check;
 	*check = vp;
@@ -155,7 +156,7 @@ int pairlist_read(const char *file, PAIR_LIST **list, int complain)
 	 */
 	while(fgets(buffer, sizeof(buffer), fp) != NULL) {
 		lineno++;
-		if (strchr(buffer, '\n') == NULL) {
+		if (!feof(fp) && (strchr(buffer, '\n') == NULL)) {
 			radlog(L_ERR, "%s[%d]: line too long", file, lineno);
 			pairlist_free(&pl);
 			return -1;
@@ -166,7 +167,7 @@ parse_again:
 			/*
 			 *	Find the entry starting with the users name
 			 */
-			if (isspace(buffer[0]))  {
+			if (isspace((int) buffer[0]))  {
 				if (parsecode != T_EOL) {
 					radlog(L_ERR|L_CONS,
 							"%s[%d]: Unexpected trailing comma for entry %s",
@@ -185,10 +186,10 @@ parse_again:
 			 *	$INCLUDE filename
 			 */
 			if (strcasecmp(entry, "$include") == 0) {
-				while(isspace(*ptr))
+				while(isspace((int) *ptr))
 					ptr++;
 				s = ptr;
-				while (!isspace(*ptr))
+				while (!isspace((int) *ptr))
 					ptr++;
 				*ptr = 0;
 
@@ -265,7 +266,8 @@ parse_again:
 				 *	Parse the reply values
 				 */
 				parsecode = userparse(buffer, &reply_tmp);
-				if (parsecode < 0) {
+				/* valid tokens are 1 or greater */
+				if (parsecode < 1) {
 					pairlist_free(&pl);
 					radlog(L_ERR|L_CONS,
 							"%s[%d]: Parse error (reply) for entry %s: %s",
@@ -384,7 +386,7 @@ int read_realms_file(const char *file)
 	}
 	while(fgets(buffer, 256, fp) != NULL) {
 		lineno++;
-		if (strchr(buffer, '\n') == NULL) {
+		if (!feof(fp) && (strchr(buffer, '\n') == NULL)) {
 			radlog(L_ERR, "%s[%d]: line too long", file, lineno);
 			return -1;
 		}
@@ -466,6 +468,7 @@ int read_realms_file(const char *file)
 		strcpy(c->server, hostnm);
 		c->striprealm = TRUE;
 		c->active = TRUE;
+		c->acct_active = TRUE;
 
 		while (getword(&p, opts, sizeof(opts))) {
 			if (strcmp(opts, "nostrip") == 0)
@@ -493,26 +496,30 @@ int read_realms_file(const char *file)
 /*
  * Mark a host inactive
  */
-void realm_disable(uint32_t ipaddr)
+void realm_disable(uint32_t ipaddr, int port)
 {
 	REALM *cl;
 	time_t now;
 
 	now = time(NULL);
 	for(cl = realms; cl; cl = cl->next)
-		if ((ipaddr == cl->ipaddr) ||
-		    (ipaddr == cl->acct_ipaddr)) {
+		if ((ipaddr == cl->ipaddr) && (port == cl->auth_port)) {
 			cl->active = FALSE;
 			cl->wakeup = now + proxy_dead_time;
-			radlog(L_PROXY, "marking server %s for realm %s dead",
-				cl->server, cl->realm);
+			radlog(L_PROXY, "marking authentication server %s:%d for realm %s dead",
+				cl->server, port, cl->realm);
+		} else if ((ipaddr == cl->acct_ipaddr) && (port == cl->acct_port)) {
+			cl->acct_active = FALSE;
+			cl->acct_wakeup = now + proxy_dead_time;
+			radlog(L_PROXY, "marking accounting server %s:%d for realm %s dead",
+				cl->server, port, cl->realm);
 		}
 }
 
 /*
  *	Find a realm in the REALM list.
  */
-REALM *realm_find(const char *realm)
+REALM *realm_find(const char *realm, int acct)
 {
 	REALM *cl;
 	REALM *default_realm = NULL;
@@ -536,11 +543,16 @@ REALM *realm_find(const char *realm)
 		if (cl->wakeup <= now) {
 			cl->active = TRUE;
 		}
+		if (cl->acct_wakeup <= now) {
+			cl->acct_active = TRUE;
+		}
 
 		/*
-		 *	It's not alive, skip it.
+		 *	Asked for auth/acct, and the auth/acct server
+		 *	is not active.  Skip it.
 		 */
-		if (!cl->active) {
+		if ((!acct && !cl->active) ||
+		    (acct && !cl->acct_active)) {
 
 			/*
 			 *	We've been asked to NOT fall through
@@ -591,11 +603,10 @@ REALM *realm_find(const char *realm)
 	return default_realm;
 }
 
-
 /*
  *	Find a realm for a proxy reply by proxy's IP
  */
-REALM *realm_findbyaddr(uint32_t ipaddr)
+REALM *realm_findbyaddr(uint32_t ipaddr, int port)
 {
 	REALM *cl;
 
@@ -606,10 +617,12 @@ REALM *realm_findbyaddr(uint32_t ipaddr)
 	 *	as active, and return the realm.
 	 */
 	for(cl = realms; cl != NULL; cl = cl->next)
-		if ((ipaddr == cl->ipaddr) ||
-		    (ipaddr == cl->acct_ipaddr)) {
+		if ((ipaddr == cl->ipaddr) && (port == cl->auth_port)) {
 			cl->active = TRUE;
 			return cl;
+		} else if ((ipaddr == cl->acct_ipaddr) && (port == cl->acct_port)) {
+			cl->acct_active = TRUE;
+			return cl;
 		}
 
 	return NULL;
