@@ -1,7 +1,7 @@
 /*
  * log.c	Logging module.
  *
- * Version:	$Id: log.c,v 1.31 2002/05/25 05:45:12 fcusack Exp $
+ * Version:	$Id: log.c,v 1.32 2002/07/22 23:10:06 ramoore Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2001  Chad Miller <cmiller@surfsouth.com>
  */
 
-static const char rcsid[] = "$Id: log.c,v 1.31 2002/05/25 05:45:12 fcusack Exp $";
+static const char rcsid[] = "$Id: log.c,v 1.32 2002/07/22 23:10:06 ramoore Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -281,3 +281,20 @@ int radlog(int lvl, const char *msg, ...)
 
 	return r;
 }
+
+
+/*
+ *      Dump a whole list of attributes to DEBUG2
+ */                     
+void vp_listdebug(VALUE_PAIR *vp)
+{       
+        char tmpPair[70];  
+        for (; vp; vp = vp->next) {
+                vp_prints(tmpPair, sizeof(tmpPair), vp);
+                DEBUG2("     %s", tmpPair);
+        }               
+}
+   
+
+ 
+        
