@@ -1,7 +1,7 @@
 /*
  * modcall.c
  *
- * Version:	$Id: modcall.c,v 1.11 2002/01/14 11:22:49 3APA3A Exp $
+ * Version:	$Id: modcall.c,v 1.14 2002/06/14 15:17:38 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
+#include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
 #include "radiusd.h"
@@ -152,6 +153,7 @@ static int str2action(const char *s, const char *filename, int lineno)
 	return -1;
 }
 
+#if 0
 static const char *action2str(int action)
 {
 	static char buf[32];
@@ -160,6 +162,7 @@ static const char *action2str(int action)
 	snprintf(buf, sizeof buf, "%d", action);
 	return buf;
 }
+#endif
 
 /* Some short names for debugging output */
 static const char *comp2str[] = {
@@ -167,7 +170,10 @@ static const char *comp2str[] = {
 	"authorize",
 	"preacct",
 	"accounting",
-	"session"
+	"session",
+	"pre-proxy",
+	"post-proxy",
+	"post-auth"
 };
 
 #if HAVE_PTHREAD_H
@@ -258,12 +264,33 @@ int modcall(int component, modcallable *c, REQUEST *request)
 
 	/* Choose a default return value appropriate for the component */
 	switch(component) {
-		case RLM_COMPONENT_AUTZ:    myresult = RLM_MODULE_NOTFOUND;break;
-		case RLM_COMPONENT_AUTH:    myresult = RLM_MODULE_REJECT;  break;
-		case RLM_COMPONENT_PREACCT: myresult = RLM_MODULE_NOOP;    break;
-		case RLM_COMPONENT_ACCT:    myresult = RLM_MODULE_NOOP;    break;
-		case RLM_COMPONENT_SESS:    myresult = RLM_MODULE_FAIL;    break;
-		default: myresult = RLM_MODULE_FAIL;
+	case RLM_COMPONENT_AUTZ:
+		myresult = RLM_MODULE_NOTFOUND;
+		break;
+	case RLM_COMPONENT_AUTH:
+		myresult = RLM_MODULE_REJECT;
+		break;
+	case RLM_COMPONENT_PREACCT:
+		myresult = RLM_MODULE_NOOP;
+		break;
+	case RLM_COMPONENT_ACCT:
+		myresult = RLM_MODULE_NOOP;
+		break;
+	case RLM_COMPONENT_SESS:
+		myresult = RLM_MODULE_FAIL;
+		break;
+	case RLM_COMPONENT_PRE_PROXY:
+		myresult = RLM_MODULE_NOOP;
+		break;
+	case RLM_COMPONENT_POST_PROXY:
+		myresult = RLM_MODULE_NOOP;
+		break;
+	case RLM_COMPONENT_POST_AUTH:
+		myresult = RLM_MODULE_NOOP;
+		break;
+	default:
+		myresult = RLM_MODULE_FAIL;
+		break;
 	}
 
 	if(c == NULL) {
@@ -294,6 +321,7 @@ int modcall(int component, modcallable *c, REQUEST *request)
 	return myresult;
 }
 
+#if 0
 /* If you suspect a bug in the parser, you'll want to use these dump
  * functions. dump_tree should reproduce a whole tree exactly as it was found
  * in radiusd.conf, but in long form (all actions explicitly defined) */
@@ -326,6 +354,12 @@ static void dump_tree(int comp, modcallable *c)
 	DEBUG("[%s]", comp2str[comp]);
 	dump_mc(c, 0);
 }
+#else
+static void dump_tree(int comp, modcallable *c)
+{
+	return;
+}
+#endif
 
 #define GROUPTYPE_SIMPLEGROUP 0
 #define GROUPTYPE_REDUNDANT 1
@@ -532,6 +566,123 @@ defaultactions[RLM_COMPONENT_COUNT][GROUPTYPE_COUNT][RLM_MODULE_NUMCODES] =
 			MOD_ACTION_RETURN,	/* noop     */
 			MOD_ACTION_RETURN	/* updated  */
 		}
+	},
+	/* pre-proxy */
+	{
+		/* group */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			MOD_ACTION_RETURN,	/* fail     */
+			3,			/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			1,			/* notfound */
+			2,			/* noop     */
+			4			/* updated  */
+		},
+		/* redundant */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			1,			/* fail     */
+			MOD_ACTION_RETURN,	/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			MOD_ACTION_RETURN,	/* notfound */
+			MOD_ACTION_RETURN,	/* noop     */
+			MOD_ACTION_RETURN	/* updated  */
+		},
+		/* append */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			1,			/* fail     */
+			MOD_ACTION_RETURN,	/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			2,			/* notfound */
+			MOD_ACTION_RETURN,	/* noop     */
+			MOD_ACTION_RETURN	/* updated  */
+		}
+	},
+	/* post-proxy */
+	{
+		/* group */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			MOD_ACTION_RETURN,	/* fail     */
+			3,			/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			1,			/* notfound */
+			2,			/* noop     */
+			4			/* updated  */
+		},
+		/* redundant */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			1,			/* fail     */
+			MOD_ACTION_RETURN,	/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			MOD_ACTION_RETURN,	/* notfound */
+			MOD_ACTION_RETURN,	/* noop     */
+			MOD_ACTION_RETURN	/* updated  */
+		},
+		/* append */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			1,			/* fail     */
+			MOD_ACTION_RETURN,	/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			2,			/* notfound */
+			MOD_ACTION_RETURN,	/* noop     */
+			MOD_ACTION_RETURN	/* updated  */
+		}
+	},
+	/* post-auth */
+	{
+		/* group */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			MOD_ACTION_RETURN,	/* fail     */
+			3,			/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			1,			/* notfound */
+			2,			/* noop     */
+			4			/* updated  */
+		},
+		/* redundant */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			1,			/* fail     */
+			MOD_ACTION_RETURN,	/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			MOD_ACTION_RETURN,	/* notfound */
+			MOD_ACTION_RETURN,	/* noop     */
+			MOD_ACTION_RETURN	/* updated  */
+		},
+		/* append */
+		{
+			MOD_ACTION_RETURN,	/* reject   */
+			1,			/* fail     */
+			MOD_ACTION_RETURN,	/* ok       */
+			MOD_ACTION_RETURN,	/* handled  */
+			MOD_ACTION_RETURN,	/* invalid  */
+			MOD_ACTION_RETURN,	/* userlock */
+			2,			/* notfound */
+			MOD_ACTION_RETURN,	/* noop     */
+			MOD_ACTION_RETURN	/* updated  */
+		}
 	}
 };
 
@@ -646,7 +797,7 @@ modcallable *compile_modsingle(int component, CONF_ITEM *ci,
 	modcallable *ret = do_compile_modsingle(component, ci, filename,
 		GROUPTYPE_SIMPLEGROUP,
 		modname);
-	/*dump_tree(component, ret);*/
+	dump_tree(component, ret);
 	return ret;
 }
 
@@ -715,7 +866,7 @@ modcallable *compile_modgroup(int component, CONF_SECTION *cs,
 	modcallable *ret = do_compile_modgroup(component, cs, filename,
 			GROUPTYPE_SIMPLEGROUP,
 			GROUPTYPE_SIMPLEGROUP);
-	/*dump_tree(component, ret);*/
+	dump_tree(component, ret);
 	return ret;
 }
 
