@@ -1,7 +1,7 @@
 /*
  * radclient.c	General radius packet debug tool.
  *
- * Version:	$Id: radclient.c,v 1.43 2002/03/11 18:50:06 aland Exp $
+ * Version:	$Id: radclient.c,v 1.46 2002/06/21 19:57:26 cparker Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Copyright 2000  Miquel van Smoorenburg <miquels@cistron.nl>
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
-static const char rcsid[] = "$Id: radclient.c,v 1.43 2002/03/11 18:50:06 aland Exp $";
+static const char rcsid[] = "$Id: radclient.c,v 1.46 2002/06/21 19:57:26 cparker Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -70,7 +70,7 @@ static char filesecret[256];
 static VALUE_PAIR *readvp(FILE *fp)
 {
 	char buf[8192];
-	int last_token;
+	LRAD_TOKEN last_token;
 	char *p;
 	VALUE_PAIR *vp;
 	VALUE_PAIR *list;
@@ -209,10 +209,11 @@ int main(int argc, char **argv)
 	int id;
 
 	id = ((int)getpid() & 0xff);
+	librad_debug = 0;
 
 	while ((c = getopt(argc, argv, "c:d:f:hi:qst:r:S:xv")) != EOF) switch(c) {
 		case 'c':
-			if (!isdigit(*optarg)) 
+			if (!isdigit((int) *optarg)) 
 				usage();
 			count = atoi(optarg);
 			break;
@@ -226,15 +227,15 @@ int main(int argc, char **argv)
 			do_output = 0;
 			break;
 		case 'x':
-			librad_debug = 1;
+			librad_debug++;
 			break;
 		case 'r':
-			if (!isdigit(*optarg)) 
+			if (!isdigit((int) *optarg)) 
 				usage();
 			retries = atoi(optarg);
 			break;
 		case 'i':
-			if (!isdigit(*optarg)) 
+			if (!isdigit((int) *optarg)) 
 				usage();
 			id = atoi(optarg);
 			if ((id < 0) || (id > 255)) {
@@ -245,12 +246,12 @@ int main(int argc, char **argv)
 			do_summary = 1;
 			break;
 		case 't':
-			if (!isdigit(*optarg)) 
+			if (!isdigit((int) *optarg)) 
 				usage();
 			timeout = atof(optarg);
 			break;
 		case 'v':
-			printf("radclient: $Id: radclient.c,v 1.43 2002/03/11 18:50:06 aland Exp $ built on " __DATE__ " at " __TIME__ "\n");
+			printf("radclient: $Id: radclient.c,v 1.46 2002/06/21 19:57:26 cparker Exp $ built on " __DATE__ " at " __TIME__ "\n");
 			exit(0);
 			break;
                case 'S':
@@ -326,7 +327,7 @@ int main(int argc, char **argv)
 		if (port == 0) port = PW_ACCT_UDP_PORT;
 		req->code = PW_ACCOUNTING_REQUEST;
 		do_summary = 0;
-	} else if (isdigit(argv[2][0])) {
+	} else if (isdigit((int) argv[2][0])) {
 		if (port == 0) port = getport("radius");
 		if (port == 0) port = PW_AUTH_UDP_PORT;
 		req->code = atoi(argv[2]);
@@ -395,6 +396,34 @@ int main(int argc, char **argv)
 			*password = '\0';
 		}
 	
+		/*
+		 *  Fix up Digest-Attributes issues
+		 */
+		for (vp = req->vps; vp != NULL; vp = vp->next) {
+		  switch (vp->attribute) {
+		  default:
+		    break;
+
+		  case PW_DIGEST_REALM:
+		  case PW_DIGEST_NONCE:
+		  case PW_DIGEST_METHOD:
+		  case PW_DIGEST_URI:
+		  case PW_DIGEST_QOP:
+		  case PW_DIGEST_ALGORITHM:
+		  case PW_DIGEST_BODY_DIGEST:
+		  case PW_DIGEST_CNONCE:
+		  case PW_DIGEST_NONCE_COUNT:
+		  case PW_DIGEST_USER_NAME:
+		    /* overlapping! */
+		    memmove(&vp->strvalue[2], &vp->strvalue[0], vp->length);
+		    vp->strvalue[0] = vp->attribute - PW_DIGEST_REALM + 1;
+		    vp->length += 2;
+		    vp->strvalue[1] = vp->length;
+		    vp->attribute = PW_DIGEST_ATTRIBUTES;
+		    break;
+		  }
+		}
+
 		/*
 		 *	Loop, sending the packet N times.
 		 */
