@@ -1,7 +1,7 @@
 /*
  * radiusd.c	Main loop of the radius server.
  *
- * Version:	$Id: radiusd.c,v 1.253 2002/06/25 20:45:13 cparker Exp $
+ * Version:	$Id: radiusd.c,v 1.256 2002/07/11 13:53:42 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 /* don't look here for the version, run radiusd -v or look in version.c */
 static const char rcsid[] =
-"$Id: radiusd.c,v 1.253 2002/06/25 20:45:13 cparker Exp $";
+"$Id: radiusd.c,v 1.256 2002/07/11 13:53:42 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -100,7 +100,6 @@ const char *radlib_dir = NULL;
 int syslog_facility;
 int log_stripped_names;
 int debug_flag = 0;
-int use_dbm = FALSE;
 uint32_t myip = INADDR_ANY;
 int log_auth_detail = FALSE;
 int auth_port = 0;
@@ -279,7 +278,11 @@ static int reread_config(int reload)
 	/* First read radiusd.conf */
 	DEBUG2("reread_config:  reading radiusd.conf");
 	if (read_radius_conf_file() < 0) {
-		radlog(L_ERR|L_CONS, "Errors reading radiusd.conf");
+		if (debug_flag) {
+			radlog(L_ERR|L_CONS, "Errors reading radiusd.conf");
+		} else {
+			radlog(L_ERR|L_CONS, "Errors reading radiusd.conf: For more information, please read the tail end of %s/%s", radlog_dir, RADIUS_LOG);
+		}
 		return -1;
 	}
 
@@ -906,6 +909,8 @@ int main(int argc, char *argv[])
 	if (spawn_flag == TRUE) {
 		thread_pool_init();
 	}
+
+	rad_exec_init();
 #endif
 
 	/*
