@@ -1,7 +1,7 @@
 /*
  * rlm_counter.c
  *
- * Version:  $Id: rlm_counter.c,v 1.17 2002/02/25 18:47:55 aland Exp $
+ * Version:  $Id: rlm_counter.c,v 1.21 2002/06/21 19:57:27 cparker Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@
 #define gdbm_fdesc(foo) (-1)
 #endif
 
-static const char rcsid[] = "$Id: rlm_counter.c,v 1.17 2002/02/25 18:47:55 aland Exp $";
+static const char rcsid[] = "$Id: rlm_counter.c,v 1.21 2002/06/21 19:57:27 cparker Exp $";
 
 /*
  *	Define a structure for our module configuration.
@@ -130,9 +130,7 @@ static int counter_cmp(void *instance, REQUEST *req, VALUE_PAIR *request, VALUE_
 	key_datum.dptr = key_vp->strvalue;
 	key_datum.dsize = key_vp->length;
 
-	if (data->fd >= 0) rad_lockfd(data->fd, sizeof(int));
 	count_datum = gdbm_fetch(data->gdbm, key_datum);
-	if (data->fd >= 0) rad_unlockfd(data->fd, sizeof(int));
 
 	if (count_datum.dptr == NULL) {
 		return -1;
@@ -156,14 +154,14 @@ static int find_next_reset(rlm_counter_t *data, time_t timeval)
 
 	if (data->reset == NULL)
 		return -1;
-	if (isdigit(data->reset[0])){
+	if (isdigit((int) data->reset[0])){
 		unsigned int len=0;
 
 		len = strlen(data->reset);
 		if (len == 0)
 			return -1;
 		last = data->reset[len - 1];
-		if (!isalpha(last))
+		if (!isalpha((int) last))
 			last = 'd';
 		num = atoi(data->reset);
 		DEBUG("rlm_counter: num=%d, last=%c",num,last);
@@ -430,7 +428,6 @@ static int counter_accounting(void *instance, REQUEST *request)
 	key_datum.dptr = key_vp->strvalue;
 	key_datum.dsize = key_vp->length;
 
-	if (data->fd >= 0) rad_lockfd(data->fd, sizeof(int));
 	count_datum = gdbm_fetch(data->gdbm, key_datum);
 	if (count_datum.dptr == NULL)
 		counter = 0;
@@ -471,7 +468,6 @@ static int counter_accounting(void *instance, REQUEST *request)
 	count_datum.dsize = sizeof(int);
 
 	rcode = gdbm_store(data->gdbm, key_datum, count_datum, GDBM_REPLACE);
-	if (data->fd >= 0) rad_unlockfd(data->fd, sizeof(int));
 	if (rcode < 0) {
 		radlog(L_ERR, "rlm_counter: Failed storing data to %s: %s",
 				data->filename, gdbm_strerror(gdbm_errno));
@@ -560,9 +556,7 @@ static int counter_authorize(void *instance, REQUEST *request)
 	key_datum.dptr = key_vp->strvalue;
 	key_datum.dsize = key_vp->length;
 	
-	if (data->fd >= 0) rad_lockfd(data->fd, sizeof(int));
 	count_datum = gdbm_fetch(data->gdbm, key_datum);
-	if (data->fd >= 0) rad_unlockfd(data->fd, sizeof(int));
 	if (count_datum.dptr != NULL){
 		memcpy(&counter, count_datum.dptr, sizeof(int));
 		free(count_datum.dptr);
@@ -616,8 +610,8 @@ static int counter_authorize(void *instance, REQUEST *request)
 				key_vp->strvalue,res);
 	}
 	else{
-		char module_msg[MAX_STRING_LEN];
-		VALUE_PAIR *module_msg_vp;
+		char module_fmsg[MAX_STRING_LEN];
+		VALUE_PAIR *module_fmsg_vp;
 
 		/*
 		 * User is denied access, send back a reply message
@@ -626,9 +620,9 @@ static int counter_authorize(void *instance, REQUEST *request)
 		reply_item=pairmake("Reply-Message", msg, T_OP_EQ);
 		pairadd(&request->reply->vps, reply_item);
 
-		snprintf(module_msg, sizeof(module_msg), "rlm_counter: Maximum %s usage time reached", data->reset);
-		module_msg_vp = pairmake("Module-Message", module_msg, T_OP_EQ);
-		pairadd(&request->packet->vps, module_msg_vp);	
+		snprintf(module_fmsg,sizeof(module_fmsg), "rlm_counter: Maximum %s usage time reached", data->reset);
+		module_fmsg_vp = pairmake("Module-Failure-Message", module_fmsg, T_OP_EQ);
+		pairadd(&request->packet->vps, module_fmsg_vp);	
 
 		ret=RLM_MODULE_REJECT;
 
