@@ -1,7 +1,7 @@
 /*
  * cb.c 
  *
- * Version:     $Id: cb.c,v 1.5 2002/04/12 22:08:12 raghu Exp $
+ * Version:     $Id: cb.c,v 1.6 2002/07/11 17:02:22 raghu Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -154,7 +154,7 @@ int cbtls_verify(int ok, X509_STORE_CTX *ctx)
 
 void cbtls_msg(int write_p, int version, int content_type, const void *buf, size_t len, SSL *ssl, void *arg)
 {
-	tls_session_t *state = arg;
+	tls_session_t *state = (tls_session_t *)arg;
 
 	state->info.origin = (unsigned char)write_p;
 	state->info.content_type = (unsigned char)content_type;
