@@ -1,7 +1,7 @@
 /*
  * eap_tls.h 
  *
- * Version:     $Id: eap_tls.h,v 1.5 2002/03/27 05:00:30 raghu Exp $
+ * Version:     $Id: eap_tls.h,v 1.7 2002/07/15 18:25:36 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -46,9 +46,13 @@
 #include <unistd.h>
 #endif
 
+#include "config.h"
+
 #ifndef NO_OPENSSL
 #include <openssl/err.h>
+#if HAVE_OPENSSL_ENGINE_H
 #include <openssl/engine.h>
+#endif
 #include <openssl/ssl.h>
 #endif /* !defined(NO_OPENSSL) */
 
@@ -242,7 +246,8 @@ typedef struct _tls_info_t {
  * clean_out - data that is cleaned after receiving.
  * dirty_out - data EAP server sends. 
  * offset    - current fragment size transmitted
- * fragment  - In Fragment mode or not. If yes, the current fragment number
+ * fragment  - Flag, In fragment mode or not.
+ * tls_msg_len - Actual/Total TLS message length.
  * length_flag - A flag to include length in every TLS Data/Alert packet
  * 					if set to no then only the first fragment contains length
  */
@@ -263,6 +268,7 @@ typedef struct _tls_session_t {
 	 * if present, can also be used to set this
 	 */
 	unsigned int 	offset;
+	unsigned int 	tls_msg_len;
 	int 		fragment;
 	int			length_flag;
 } tls_session_t;
