@@ -2,7 +2,7 @@
  * rlm_fastusers.c	authorization: Find a user in the hashed "users" file.
  *                	accounting:    Do nothing.  Auth module only.
  *
- * Version:	$Id: rlm_fastusers.c,v 1.22 2001/03/19 20:52:19 jcarneal Exp $
+ * Version:	$Id: rlm_fastusers.c,v 1.25 2001/11/09 00:53:10 kkalev Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  */
 
-#include	"autoconf.h"
-#include "libradius.h"
+#include        "autoconf.h"
+#include        "libradius.h"
 
 #include	<sys/socket.h>
 #include	<sys/time.h>
@@ -55,6 +55,8 @@ struct fastuser_instance {
 	char *usersfile;
 	char *acctusersfile;
 	time_t next_reload;
+	time_t lastusersload;
+	time_t lastacctusersload;
 };
 
 /* Function declarations */
@@ -102,6 +104,9 @@ static int fastuser_buildhash(struct fastuser_instance *inst) {
 	PAIR_LIST **newhash=NULL, **oldhash=NULL;
 	PAIR_LIST *newdefaults=NULL, *newacctusers, *cur=NULL;
 	PAIR_LIST *olddefaults=NULL, *oldacctusers=NULL;
+	struct stat statbuf;
+	int reloadusers = 1;
+	int reloadacctusers = 1;
 
 	/* 
 	 * Allocate space for hash table here
@@ -112,45 +117,73 @@ static int fastuser_buildhash(struct fastuser_instance *inst) {
 
 	memset((PAIR_LIST *)newhash, 0, memsize);
 
+	/* Check acct_users last modification time */
+	if ((stat(inst->acctusersfile, &statbuf) != -1)
+	 && (statbuf.st_mtime <= inst->lastacctusersload)) {
+		DEBUG2("rlm_fastusers:  File %s was unchanged. Not reloading.",
+			inst->acctusersfile);
+		reloadacctusers = 0;
+		rcode = 0;
+	}
+	else
 	/* Read acct_users */
 	rcode = fastuser_getfile(inst, inst->acctusersfile, NULL, &newacctusers, 1);
+
 	if (rcode != 0) {
 		radlog(L_ERR|L_CONS, "rlm_fastusers:  Errors reading %s", inst->usersfile);
 		return -1;
 	}
 
+	/* Check users last modification time */
+	if ((stat(inst->usersfile, &statbuf) != -1)
+	 && (statbuf.st_mtime <= inst->lastusersload)) {
+		DEBUG2("rlm_fastusers:  File %s was unchanged. Not reloading.",
+			inst->usersfile);
+		reloadusers = 0;
+		rcode = 0;
+		/* This was allocated earlier but will remain unused */
+		free(newhash);
+	}
+	else
 	/* Read users */
 	rcode = fastuser_getfile(inst, inst->usersfile, &newdefaults, newhash, 0);
+
 	if (rcode != 0) {
 		radlog(L_ERR|L_CONS, "rlm_fastusers:  Errors reading %s", inst->usersfile);
 		return -1;
 	}
 
-	/*
-	 * We need to do this now so that users auths
-	 * aren't blocked while we free the old table
-	 * below
-	 */
-	oldacctusers = inst->acctusers;
-	inst->acctusers = newacctusers;
-	oldhash = inst->hashtable;
-	inst->hashtable = newhash;
-	olddefaults = inst->defaults;
-	inst->defaults = newdefaults;
+	if (reloadusers) {
+		/*
+		 * We need to do this now so that users auths
+		 * aren't blocked while we free the old table
+		 * below
+		 */
+		inst->lastusersload = time(NULL);
+		oldhash = inst->hashtable;
+		inst->hashtable = newhash;
+		olddefaults = inst->defaults;
+		inst->defaults = newdefaults;
 
-	/*
-	 * When we get here, we assume the hash built properly.
-	 * So we begin to tear down the old one
-	 */
-	if(oldhash) {
-		for(hashindex=0; hashindex<inst->hashsize; hashindex++) {
-			if(oldhash[hashindex]) {
-				cur = oldhash[hashindex];
-				pairlist_free(&cur);
-			}
-		} 
-		free(oldhash);
+		/*
+		 * When we get here, we assume the hash built properly.
+		 * So we begin to tear down the old one
+		 */
+		if (oldhash) {
+			for(hashindex=0; hashindex<inst->hashsize; hashindex++) {
+				if(oldhash[hashindex]) {
+					cur = oldhash[hashindex];
+					pairlist_free(&cur);
+				}
+			} 
+			free(oldhash);
+		}
 		pairlist_free(&olddefaults);
+	}
+	if (reloadacctusers) {
+		inst->lastacctusersload = time(NULL);
+		oldacctusers = inst->acctusers;
+		inst->acctusers = newacctusers;
 		pairlist_free(&oldacctusers);
 	}
 
@@ -383,7 +416,7 @@ static PAIR_LIST *fastuser_find(REQUEST *request, PAIR_LIST *user,
 	 */
 	while((cur) && (!userfound)) {
 		if((strcmp(cur->name, username)==0) &&
-				paircmp(request->packet->vps, cur->check, &request->reply->vps) == 0) {
+				paircmp(request, request->packet->vps, cur->check, &request->reply->vps) == 0) {
 			/*
 			 * Usercollide means we have to compare check pairs
 			 * AND the password
@@ -500,6 +533,8 @@ static int fastuser_instantiate(CONF_SECTION *conf, void **instance)
 
 	inst->next_reload = time(NULL) + inst->hash_reload;
 	inst->hashtable = NULL;
+	inst->lastusersload = 0;
+	inst->lastacctusersload = 0;
 	if(fastuser_buildhash(inst) < 0) {
 		radlog(L_ERR, "rlm_fastusers:  error building user hash.  aborting");
 		return -1;
@@ -579,7 +614,7 @@ static int fastuser_authorize(void *instance, REQUEST *request)
 
 		if(!fallthrough(user->reply)) {
 			pairdelete(&request->reply->vps, PW_FALL_THROUGH);
-			return RLM_MODULE_UPDATED;
+			return(rad_check_return(user->check));
 		} else {
 			user=user->next;
 			user=fastuser_find(request, user, name);
@@ -599,7 +634,7 @@ static int fastuser_authorize(void *instance, REQUEST *request)
 			
 	curdefault = inst->defaults;
 	while(curdefault) {
-		if(paircmp(request->packet->vps, curdefault->check, 
+		if(paircmp(request, request->packet->vps, curdefault->check, 
 							&request->reply->vps) == 0) {
 			DEBUG2("  fastusers: Matched %s at %d", 
 							curdefault->name, curdefault->lineno);
@@ -643,7 +678,7 @@ static int fastuser_authorize(void *instance, REQUEST *request)
 
 			if(!fallthrough(user->reply)) {
 				pairdelete(&request->reply->vps, PW_FALL_THROUGH);
-				return RLM_MODULE_UPDATED;
+				return(rad_check_return(user->check));
 			}
 
 			/* 
@@ -659,7 +694,7 @@ static int fastuser_authorize(void *instance, REQUEST *request)
 
 	if(userfound || defaultfound) {
 		pairdelete(&request->reply->vps, PW_FALL_THROUGH);
-		return RLM_MODULE_UPDATED;
+		return(rad_check_return(request->config_items));
 	} else {
 		DEBUG2("rlm_fastusers:  user not found");
 		return RLM_MODULE_NOTFOUND;
@@ -709,7 +744,7 @@ static int fastuser_preacct(void *instance, REQUEST *request)
 		if (strcmp(name, pl->name) && strcmp(pl->name, "DEFAULT"))
 			continue;
 
-		if (paircmp(request_pairs, pl->check, &reply_pairs) == 0) {
+		if (paircmp(request, request_pairs, pl->check, &reply_pairs) == 0) {
 			DEBUG2("  acct_users: Matched %s at %d",
 			       pl->name, pl->lineno);
 			found = 1;
