@@ -28,7 +28,7 @@ int	sql_select_query(SQLSOCK *sqlsocket, SQL_CONFIG *config, char *querystr);
 int	sql_store_result(SQLSOCK * sqlsocket, SQL_CONFIG *config);
 int	sql_num_fields(SQLSOCK * sqlsocket, SQL_CONFIG *config);
 int	sql_num_rows(SQLSOCK * sqlsocket, SQL_CONFIG *config);
-SQL_ROW	sql_fetch_row(SQLSOCK * sqlsocket, SQL_CONFIG *config);
+int	sql_fetch_row(SQLSOCK * sqlsocket, SQL_CONFIG *config);
 int	sql_free_result(SQLSOCK * sqlsocket, SQL_CONFIG *config);
 char	*sql_error(SQLSOCK * sqlsocket, SQL_CONFIG *config);
 int	sql_close(SQLSOCK * sqlsocket, SQL_CONFIG *config);
