@@ -3,7 +3,7 @@
  *		accounting:     Functions to write radwtmp file.
  *		Also contains handler for "Group".
  *
- * Version:	$Id: rlm_unix.c,v 1.45 2002/02/26 19:22:24 aland Exp $
+ * Version:	$Id: rlm_unix.c,v 1.46 2002/05/06 14:29:41 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  * Copyright 2000  Alan Curry <pacman@world.std.com>
  */
-static const char rcsid[] = "$Id: rlm_unix.c,v 1.45 2002/02/26 19:22:24 aland Exp $";
+static const char rcsid[] = "$Id: rlm_unix.c,v 1.46 2002/05/06 14:29:41 aland Exp $";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -218,10 +218,18 @@ static int groupcmp(void *instance, REQUEST *req, VALUE_PAIR *request, VALUE_PAI
 	    (retval = H_groupcmp(group_inst->cache, check, username)) != -2)
 		return retval;
 
-	if ((pwd = fgetpwnam(group_inst->passwd_file, username)) == NULL)
+	if (group_inst->passwd_file)
+		pwd = fgetpwnam(group_inst->passwd_file, username);
+	else
+		pwd = getpwnam(username);
+	if (pwd == NULL)
 		return -1;
 
-	if ((grp = fgetgrnam(group_inst->group_file, (char *)check->strvalue)) == NULL)
+	if (group_inst->group_file)
+		grp = fgetgrnam(group_inst->passwd_file, (char *)check->strvalue);
+	else
+		grp = getgrnam((char *)check->strvalue);
+	if (grp == NULL)
 		return -1;
 
 	retval = (pwd->pw_gid == grp->gr_gid) ? 0 : -1;
