@@ -1,6 +1,6 @@
 /*
  * x99.h
- * $Id: x99.h,v 1.11 2002/01/17 04:02:17 fcusack Exp $
+ * $Id: x99.h,v 1.16 2002/07/03 09:03:47 fcusack Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,20 +22,29 @@
 #ifndef X99_H
 #define X99_H
 
-#include "radiusd.h"     /* REQUEST */
-#include "libradius.h"   /* VALUE_PAIR */
+#include <inttypes.h>
 #include <openssl/des.h> /* des_cblock */
+#include <time.h>        /* time_t */
 
 /*
- * Things you might like to change
+ * Things you might like to change (although most are configurables)
  */
 
-/* Default text for presentation of challenge */
-#define CHALLENGE_TEXT "Challenge: %s\n Response: "
+/* Default passwd file */
+#define PWDFILE "/etc/x99passwd"
+
+/* Default sync dir */
+#define SYNCDIR "/etc/x99sync.d"
+
+/* Default prompt for presentation of challenge */
+#define CHALLENGE_PROMPT "Challenge: %s\n Response: "
+
 /* Must be a multiple of sizeof(des_cblock) (8); read docs before changing. */
 #define MAX_CHALLENGE_LEN 32
+
 /* Password that means "challenge me" in fast_sync mode */
 #define CHALLENGE_REQ "challenge"
+
 /* Password that means "challenge me and resync" in fast_sync mode */
 #define RESYNC_REQ "resync"
 
@@ -56,13 +65,12 @@
  */
 
 
-/* struct used for instance data */
+/* struct used for instance/option data */
 typedef struct x99_token_t {
     char *pwdfile;	/* file containing user:card_type:key entries      */
     char *syncdir;	/* dir containing sync mode and state info         */
-    char *chal_text;	/* text to present challenge to user, must have %s */
+    char *chal_prompt;	/* text to present challenge to user, must have %s */
     int chal_len;	/* challenge length, min 5 digits                  */
-    int maxdelay;	/* max delay time for response, in seconds         */
     int softfail;	/* number of auth fails before time delay starts   */
     int hardfail;	/* number of auth fails when user is locked out    */
     int allow_sync;	/* useful to override pwdfile card_type settings   */
@@ -71,10 +79,18 @@ typedef struct x99_token_t {
     char *chal_req;	/* keyword requesting challenge for fast_sync mode */
     char *resync_req;	/* keyword requesting resync for fast_sync mode    */
     int ewindow_size;	/* sync mode event window size (right side value)  */
+#if defined(FREERADIUS)
+    /* freeradius-specific items */
+    int maxdelay;		/* max delay time for response, in seconds */
     int mschapv2_mppe_policy;	/* whether or not do to mppe for mschapv2  */
     int mschapv2_mppe_types;	/* key type/length for mschapv2/mppe       */
     int mschap_mppe_policy;	/* whether or not do to mppe for mschap    */
     int mschap_mppe_types;	/* key type/length for mschap/mppe         */
+#elif defined(PAM)
+    /* PAM specific items */
+    int debug;		/* print debug info?                               */
+    char *fast_prompt;	/* fast mode prompt                                */
+#endif
 #if 0
     int twindow_min;	/* sync mode time window left side                 */
     int twindow_max;	/* sync mode time window right side                */
@@ -85,8 +101,8 @@ typedef struct x99_token_t {
 #define X99_CF_NONE		0
 /* Vendors */
 #define X99_CF_CRYPTOCARD	0x01 << 0  /* CRYPTOCard             */
-#define X99_CF_SNK		0x01 << 1  /* Symantec ne Axent ne   */
-					   /* AssureNet Pathways ne  */
+#define X99_CF_SNK		0x01 << 1  /* Symantec nee Axent nee */
+					   /* AssureNet Pathways nee */
 					   /* Digital Pathways       */
 					   /* "SecureNet Key"        */
 #define X99_CF_ACTIVCARD	0x01 << 2  /* ActivCard              */
@@ -133,12 +149,6 @@ extern int x99_response(const char *challenge, char response[17],
 			uint32_t card_id, des_cblock keyblock);
 extern int x99_mac(const char *input, des_cblock output, des_cblock keyblock);
 
-/* x99_state.c */
-extern int x99_gen_state(char **ascii_state, unsigned char **raw_state,
-			 const char challenge[MAX_CHALLENGE_LEN + 1],
-			 int32_t flags, int32_t when,
-			 const unsigned char key[16]);
-
 /* x99_util.c */
 /* Character maps for generic hex and vendor specific decimal modes */
 extern const char x99_hex_conversion[];
@@ -146,6 +156,7 @@ extern const char x99_cc_dec_conversion[];
 extern const char x99_snk_dec_conversion[];
 extern const char x99_sc_friendly_conversion[];
 
+extern int x99_get_challenge(int fd, char *challenge, int len);
 extern int x99_get_random(int fd, unsigned char *rnd_data, int req_bytes);
 
 extern int x99_string_to_keyblock(const char *s, des_cblock keyblock);
@@ -162,8 +173,7 @@ extern int x99_get_sync_data(const char *syncdir, const char *username,
 			     des_cblock keyblock);
 extern int x99_set_sync_data(const char *syncdir, const char *username,
 			     const char *challenge, const des_cblock keyblock);
-extern int x99_get_failcount(const char *syncdir, const char *username,
-			     int *failcount);
+extern int x99_check_failcount(const char *syncdir, const x99_token_t *inst);
 extern int x99_incr_failcount(const char *syncdir, const char *username);
 extern int x99_reset_failcount(const char *syncdir, const char *username);
 extern int x99_get_last_auth(const char *syncdir, const char *username,
@@ -174,11 +184,14 @@ extern int x99_upd_last_auth(const char *syncdir, const char *username);
 extern int x99_challenge_transform(const char *username,
 				   char challenge[MAX_CHALLENGE_LEN + 1]);
 
-/* x99_pwe.c */
-extern void x99_pwe_init(void);
-extern int x99_pw_present(const REQUEST *request);
-extern int x99_pw_valid(const REQUEST *request, x99_token_t *inst,
-			int attr, const char *password, VALUE_PAIR **vps);
+/* x99_log.c */
+extern void x99_log(int level, const char *format, ...);
+
+#if defined(FREERADIUS)
+#include "x99_rad.h"
+#elif defined(PAM)
+#include "x99_pam.h"
+#endif
 
 #endif /* X99_H */
 
